@@ -11,11 +11,13 @@
 #define LIBXMLXX_MAJOR_VERSION 5
 
 /* Minor version number of libxml++. */
-#define LIBXMLXX_MINOR_VERSION 0
+#define LIBXMLXX_MINOR_VERSION 2
 
 /* Micro version number of libxml++. */
 #define LIBXMLXX_MICRO_VERSION 0
 
+#undef LIBXMLXX_STATIC
+
 // Enable DLL-specific stuff only when not building a static library
 #if !defined(__CYGWIN__) && (defined(__MINGW32__) || defined(_MSC_VER)) && !defined(LIBXMLXX_STATIC)
 # define LIBXMLPP_DLL 1
@@ -24,13 +26,26 @@
 #ifdef LIBXMLPP_DLL
   #ifdef LIBXMLPP_BUILD
     #define LIBXMLPP_API __declspec(dllexport)
-  #else
+    #ifdef __GNUC__
+      #define LIBXMLPP_VISIBILITY_DEFAULT LIBXMLPP_API __attribute__((visibility("default")))
+      #define LIBXMLPP_MEMBER_METHOD
+    #endif
+  #elif !defined (__GNUC__)
     #define LIBXMLPP_API __declspec(dllimport)
+  #else /* don't dllimport classes/methods on GCC/MinGW */
+    #define LIBXMLPP_API
   #endif /* LIBXMLPP_BUILD - DLL */
 #else
   /* Build a static library or a non-Windows library*/
   #define LIBXMLPP_API
 #endif /* GLIBMM_DLL */
 
+#ifndef LIBXMLPP_VISIBILITY_DEFAULT
+  #define LIBXMLPP_VISIBILITY_DEFAULT
+#endif
+#ifndef LIBXMLPP_MEMBER_METHOD
+  #define LIBXMLPP_MEMBER_METHOD LIBXMLPP_API
+#endif
+
 #endif /* _LIBXMLPP_CONFIG_H */
 
